@@ -5,7 +5,7 @@ def test( doc2 )
   doc = XML::Document.new('1.0')
   doc.root = XML::Node.new("ccc")
   doc.root['aaa'] = 'aaa'
-  #doc.root << doc2.root # BUG!
+  doc.root << doc2.root # BUG!
   doc.root << doc2.root.copy(true)
   return doc
 end
