@@ -1,8 +1,8 @@
-# $Id: tc_xml_node_xlink.rb,v 1.3 2006/04/17 13:30:18 roscopeco Exp $
+# $Id: tc_xml_node_xlink.rb,v 1.4 2006/11/20 01:22:08 roscopeco Exp $
 require "libxml_test"
 require 'test/unit'
 
-class TC_XML_Node3 < Test::Unit::TestCase
+class TC_XML_Node_XLink < Test::Unit::TestCase
   def setup()
     xp = XML::Parser.new()
     str = '<ruby_array xmlns:xlink="http://www.w3.org/1999/xlink/namespace/"><fixnum xlink:type="simple">one</fixnum></ruby_array>'
